# py-fumen-util
Python implementation of [swng's FumenUtil](https://github.com/swng/FumenUtil), using [hsohliyt105's py-fumen](https://github.com/hsohliyt105/py-fumen)

# Dependency
- `py-fumen`: Python implementation of knewjade's `tetris-fumen` node module
